@@ -2,7 +2,7 @@
 /**
  *  @brief NLopt solver
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -118,17 +118,6 @@ UnsignedInteger NLopt::getSeed() const
   return seed_;
 }
 
-void NLopt::SetSeed(const UnsignedInteger seed)
-{
-  LOGWARN(OSS() << "NLopt.SetSeed is deprecated in favor of setSeed");
-#ifdef OPENTURNS_HAVE_NLOPT
-  nlopt::srand(seed);
-#else
-  (void)seed;
-  throw NotYetImplementedException(HERE) << "No NLopt support";
-#endif
-}
-
 /* Default constructor */
 NLopt::NLopt(const String & algoName)
   : OptimizationAlgorithmImplementation()
@@ -243,7 +232,9 @@ void NLopt::run()
   opt.set_xtol_abs(getMaximumAbsoluteError());
   opt.set_xtol_rel(getMaximumRelativeError());
   opt.set_ftol_rel(getMaximumResidualError());
-  opt.set_maxeval(getMaximumEvaluationNumber());
+  opt.set_maxeval(getMaximumCallsNumber());
+  if (getMaximumTimeDuration() > 0.0)
+    opt.set_maxtime(getMaximumTimeDuration());
 
   if (getProblem().hasBounds())
   {
@@ -292,7 +283,7 @@ void NLopt::run()
     local_opt.set_xtol_abs(getMaximumAbsoluteError());
     local_opt.set_xtol_rel(getMaximumRelativeError());
     local_opt.set_ftol_rel(getMaximumResidualError());
-    local_opt.set_maxeval(getMaximumEvaluationNumber());
+    local_opt.set_maxeval(getMaximumCallsNumber());
     opt.set_local_optimizer(local_opt);
   }
   else
@@ -303,7 +294,7 @@ void NLopt::run()
     local_opt.set_xtol_abs(p_localSolver_->getMaximumAbsoluteError());
     local_opt.set_xtol_rel(p_localSolver_->getMaximumRelativeError());
     local_opt.set_ftol_rel(p_localSolver_->getMaximumResidualError());
-    local_opt.set_maxeval(p_localSolver_->getMaximumEvaluationNumber());
+    local_opt.set_maxeval(p_localSolver_->getMaximumCallsNumber());
     if (p_localSolver_->getInitialStep().getDimension() > 0)
     {
       Point localInitialStep(p_localSolver_->getInitialStep());
@@ -318,29 +309,29 @@ void NLopt::run()
 
   // the default seed is non-deterministic
   nlopt::srand(seed_);
+  nlopt::result rc = nlopt::FAILURE;
 
   try
   {
     // The C++ interface of NLopt does not return a code for failures cases.
     // It is either positive (termination criterion) or an exception is thrown.
     p_opt_ = &opt;
-    const int rc = opt.optimize(x, optimalValue);
-    if (rc == nlopt::MAXEVAL_REACHED)
-      LOGDEBUG("NLopt rc=MAXEVAL_REACHED");
+    rc = opt.optimize(x, optimalValue);
   }
   catch (const nlopt::roundoff_limited &)
   {
-    // Here we catch the roundoff_limited exception as the result
-    // of the optimization may be useful even if not at the requested precision
-    LOGWARN("NLopt raised a roundoff-limited exception");
+    rc = nlopt::ROUNDOFF_LIMITED;
   }
   catch (const nlopt::forced_stop &)
   {
-    LOGWARN("NLopt was stopped by user");
+    rc = nlopt::FORCED_STOP;
   }
-  catch (const std::exception & exc)
+  catch (const std::bad_alloc &)
+  {
+    rc = nlopt::OUT_OF_MEMORY;
+  }
+  catch (const std::exception &)
   {
-    throw InternalException(HERE) << "NLopt raised an exception: " << exc.what();
   }
   p_opt_ = nullptr;
 
@@ -350,6 +341,24 @@ void NLopt::run()
     inequalityConstraintHistory_ = getProblem().getInequalityConstraint()(evaluationInputHistory_);
 
   setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_, inequalityConstraintHistory_, equalityConstraintHistory_);
+  result_.setStatusMessage(nlopt_result_to_string((nlopt_result)rc));
+  if (rc == nlopt::MAXTIME_REACHED)
+    result_.setStatus(OptimizationResult::TIMEOUT);
+  else if ((rc == nlopt::MAXEVAL_REACHED) && (algoName_[0] != 'G')) // global algorithms never converge, do not return an error
+    result_.setStatus(OptimizationResult::MAXIMUMCALLS);
+  else if (rc == nlopt::FORCED_STOP)
+    result_.setStatus(OptimizationResult::INTERRUPTION);
+  else if (rc < 0)
+    result_.setStatus(OptimizationResult::FAILURE);
+
+  if (result_.getStatus() != OptimizationResult::SUCCESS)
+  {
+    if (getCheckStatus())
+      throw InternalException(HERE) << "NLopt raised an exception: " << result_.getStatusMessage();
+    else
+      LOGWARN(OSS() << "NLopt algorithm failed: " << result_.getStatusMessage());
+  }
+
 #else
   (void) p_opt_;
   throw NotYetImplementedException(HERE) << "No NLopt support";
@@ -449,7 +458,7 @@ double NLopt::ComputeObjective(const std::vector<double> & x, std::vector<double
   algorithm->evaluationOutputHistory_.add(outP);
 
   // update result
-  algorithm->result_.setEvaluationNumber(algorithm->evaluationInputHistory_.getSize());
+  algorithm->result_.setCallsNumber(algorithm->evaluationInputHistory_.getSize());
   algorithm->result_.store(inP, outP, 0.0, 0.0, 0.0, 0.0);
 
   // gradient
@@ -470,7 +479,7 @@ double NLopt::ComputeObjective(const std::vector<double> & x, std::vector<double
   // callbacks
   if (algorithm->progressCallback_.first)
   {
-    algorithm->progressCallback_.first((100.0 * algorithm->evaluationInputHistory_.getSize()) / algorithm->getMaximumEvaluationNumber(), algorithm->progressCallback_.second);
+    algorithm->progressCallback_.first((100.0 * algorithm->evaluationInputHistory_.getSize()) / algorithm->getMaximumCallsNumber(), algorithm->progressCallback_.second);
   }
   if (algorithm->stopCallback_.first)
   {
