@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationResult stores the result of a OptimizationAlgorithmImplementation
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/SpecFunc.hxx"
+#include "openturns/Compact.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -33,23 +34,17 @@ static const Factory<OptimizationResult> Factory_OptimizationResult;
 OptimizationResult::OptimizationResult()
   : PersistentObject()
 {
-  absoluteErrorHistory_.setDimension(1);
-  relativeErrorHistory_.setDimension(1);
-  residualErrorHistory_.setDimension(1);
-  constraintErrorHistory_.setDimension(1);
+
 }
 
 /* Default constructor */
 OptimizationResult::OptimizationResult(const OptimizationProblem & problem)
   : PersistentObject()
+  , inputHistory_(0, problem.getObjective().getInputDimension())
+  , outputHistory_(0, problem.getObjective().getOutputDimension())
   , problem_(problem)
 {
-  absoluteErrorHistory_.setDimension(1);
-  relativeErrorHistory_.setDimension(1);
-  residualErrorHistory_.setDimension(1);
-  constraintErrorHistory_.setDimension(1);
-  inputHistory_.setDimension(problem.getObjective().getInputDimension());
-  outputHistory_.setDimension(problem.getObjective().getOutputDimension());
+
 }
 
 /* Virtual constructor */
@@ -110,15 +105,27 @@ void OptimizationResult::setFinalValues(const Sample & finalValues)
   finalValues_ = finalValues;
 }
 
-/* Evaluation number accessor */
+/* Evaluation calls accessor */
+UnsignedInteger OptimizationResult::getCallsNumber() const
+{
+  return callsNumber_;
+}
+
+void OptimizationResult::setCallsNumber(const UnsignedInteger callsNumber)
+{
+  callsNumber_ = callsNumber;
+}
+
 UnsignedInteger OptimizationResult::getEvaluationNumber() const
 {
-  return evaluationNumber_;
+  LOGWARN("OptimizationResult.getEvaluationNumber is deprecated, use getCallsNumber");
+  return getCallsNumber();
 }
 
 void OptimizationResult::setEvaluationNumber(const UnsignedInteger evaluationNumber)
 {
-  evaluationNumber_ = evaluationNumber;
+  LOGWARN("OptimizationResult.setEvaluationNumber is deprecated, use setCallsNumber");
+  setCallsNumber(evaluationNumber);
 }
 
 /* Iteration number accessor */
@@ -140,7 +147,7 @@ Scalar OptimizationResult::getAbsoluteError() const
 
 Sample OptimizationResult::getAbsoluteErrorHistory() const
 {
-  return absoluteErrorHistory_.getSample();
+  return absoluteErrorHistory_;
 }
 
 /* Absolute error accessor */
@@ -157,7 +164,7 @@ Scalar OptimizationResult::getRelativeError() const
 
 Sample OptimizationResult::getRelativeErrorHistory() const
 {
-  return relativeErrorHistory_.getSample();
+  return relativeErrorHistory_;
 }
 
 /* Relative error accessor */
@@ -174,7 +181,7 @@ Scalar OptimizationResult::getResidualError() const
 
 Sample OptimizationResult::getResidualErrorHistory() const
 {
-  return residualErrorHistory_.getSample();
+  return residualErrorHistory_;
 }
 
 /* Residual error accessor */
@@ -191,7 +198,7 @@ Scalar OptimizationResult::getConstraintError() const
 
 Sample OptimizationResult::getConstraintErrorHistory() const
 {
-  return constraintErrorHistory_.getSample();
+  return constraintErrorHistory_;
 }
 
 /* Constraint error accessor */
@@ -202,12 +209,12 @@ void OptimizationResult::setConstraintError(const Scalar constraintError)
 
 Sample OptimizationResult::getInputSample() const
 {
-  return inputHistory_.getSample();
+  return inputHistory_;
 }
 
 Sample OptimizationResult::getOutputSample() const
 {
-  return outputHistory_.getSample();
+  return outputHistory_;
 }
 
 void OptimizationResult::setProblem(const OptimizationProblem & problem)
@@ -225,9 +232,11 @@ String OptimizationResult::__repr__() const
 {
   OSS oss;
   oss << "class=" << OptimizationResult::GetClassName()
+      << " status=" << status_
+      << " statusMessage=" << statusMessage_
       << " optimal point=" << optimalPoint_
       << " optimal value=" << optimalValue_
-      << " evaluationNumber=" << evaluationNumber_
+      << " callsNumber=" << callsNumber_
       << " iterationNumber=" << iterationNumber_
       << " absoluteError=" << getAbsoluteError()
       << " relativeError=" << getRelativeError()
@@ -243,25 +252,28 @@ void OptimizationResult::save(Advocate & adv) const
   PersistentObject::save(adv);
   adv.saveAttribute( "optimalPoint_", optimalPoint_ );
   adv.saveAttribute( "optimalValue_", optimalValue_ );
-  adv.saveAttribute( "evaluationNumber_", evaluationNumber_ );
+  adv.saveAttribute( "callsNumber_", callsNumber_ );
   adv.saveAttribute( "iterationNumber_", iterationNumber_ );
   adv.saveAttribute( "absoluteError_", absoluteError_ );
   adv.saveAttribute( "relativeError_", relativeError_ );
   adv.saveAttribute( "residualError_", residualError_ );
   adv.saveAttribute( "constraintError_", constraintError_ );
 
-  adv.saveAttribute( "absoluteErrorHistory_", absoluteErrorHistory_ );
-  adv.saveAttribute( "relativeErrorHistory_", relativeErrorHistory_ );
-  adv.saveAttribute( "residualErrorHistory_", residualErrorHistory_ );
-  adv.saveAttribute( "constraintErrorHistory_", constraintErrorHistory_ );
+  adv.saveAttribute( "absoluteErrorHistory_S", absoluteErrorHistory_ );
+  adv.saveAttribute( "relativeErrorHistory_S", relativeErrorHistory_ );
+  adv.saveAttribute( "residualErrorHistory_S", residualErrorHistory_ );
+  adv.saveAttribute( "constraintErrorHistory_S", constraintErrorHistory_ );
 
-  adv.saveAttribute( "inputHistory_", inputHistory_ );
-  adv.saveAttribute( "outputHistory_", outputHistory_ );
+  adv.saveAttribute( "inputHistory_S", inputHistory_ );
+  adv.saveAttribute( "outputHistory_S", outputHistory_ );
 
   adv.saveAttribute( "problem_", problem_ );
   adv.saveAttribute( "finalPoints_", finalPoints_ );
   adv.saveAttribute( "finalValues_", finalValues_ );
   adv.saveAttribute( "paretoFrontsIndices_", paretoFrontsIndices_ );
+  adv.saveAttribute( "statusMessage_", statusMessage_ );
+  adv.saveAttribute( "status_", status_ );
+  adv.saveAttribute( "time_", time_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -270,20 +282,47 @@ void OptimizationResult::load(Advocate & adv)
   PersistentObject::load(adv);
   adv.loadAttribute( "optimalPoint_", optimalPoint_ );
   adv.loadAttribute( "optimalValue_", optimalValue_ );
-  adv.loadAttribute( "evaluationNumber_", evaluationNumber_ );
+  if (adv.hasAttribute("callsNumber_"))
+    adv.loadAttribute( "callsNumber_", callsNumber_ );
+  else
+    adv.loadAttribute( "evaluationNumber_", callsNumber_ );
   adv.loadAttribute( "iterationNumber_", iterationNumber_ );
   adv.loadAttribute( "absoluteError_", absoluteError_ );
   adv.loadAttribute( "relativeError_", relativeError_ );
   adv.loadAttribute( "residualError_", residualError_ );
   adv.loadAttribute( "constraintError_", constraintError_ );
 
-  adv.loadAttribute( "absoluteErrorHistory_", absoluteErrorHistory_ );
-  adv.loadAttribute( "relativeErrorHistory_", relativeErrorHistory_ );
-  adv.loadAttribute( "residualErrorHistory_", residualErrorHistory_ );
-  adv.loadAttribute( "constraintErrorHistory_", constraintErrorHistory_ );
+  if (adv.hasAttribute("inputHistory_S")) // Sample instead of Compact in 1.23
+  {
+    adv.loadAttribute( "absoluteErrorHistory_S", absoluteErrorHistory_ );
+    adv.loadAttribute( "relativeErrorHistory_S", relativeErrorHistory_ );
+    adv.loadAttribute( "residualErrorHistory_S", residualErrorHistory_ );
+    adv.loadAttribute( "constraintErrorHistory_S", constraintErrorHistory_ );
 
-  adv.loadAttribute( "inputHistory_", inputHistory_ );
-  adv.loadAttribute( "outputHistory_", outputHistory_ );
+    adv.loadAttribute( "inputHistory_S", inputHistory_ );
+    adv.loadAttribute( "outputHistory_S", outputHistory_ );
+  }
+  else
+  {
+    Compact inputHistory;
+    Compact outputHistory;
+    Compact absoluteErrorHistory;
+    Compact relativeErrorHistory;
+    Compact residualErrorHistory;
+    Compact constraintErrorHistory;
+    adv.loadAttribute( "absoluteErrorHistory_", absoluteErrorHistory );
+    adv.loadAttribute( "relativeErrorHistory_", relativeErrorHistory );
+    adv.loadAttribute( "residualErrorHistory_", residualErrorHistory );
+    adv.loadAttribute( "constraintErrorHistory_", constraintErrorHistory );
+    adv.loadAttribute( "inputHistory_", inputHistory );
+    adv.loadAttribute( "outputHistory_", outputHistory );
+    inputHistory_ = inputHistory.getSample();
+    outputHistory_ = outputHistory.getSample();
+    absoluteErrorHistory_ = absoluteErrorHistory.getSample();
+    relativeErrorHistory_ = relativeErrorHistory.getSample();
+    residualErrorHistory_ = residualErrorHistory.getSample();
+    constraintErrorHistory_ = constraintErrorHistory.getSample();
+  }
 
   adv.loadAttribute( "problem_", problem_ );
   if (adv.hasAttribute("finalPoints_"))
@@ -292,6 +331,12 @@ void OptimizationResult::load(Advocate & adv)
     adv.loadAttribute( "finalValues_", finalValues_ );
     adv.loadAttribute( "paretoFrontsIndices_", paretoFrontsIndices_ );
   }
+  if (adv.hasAttribute("status_"))
+  {
+    adv.loadAttribute("statusMessage_", statusMessage_);
+    adv.loadAttribute("status_", status_);
+    adv.loadAttribute("time_", time_);
+  }
 }
 
 /* Incremental history storage */
@@ -303,14 +348,31 @@ void OptimizationResult::store(const Point & x,
                                const Scalar constraintError,
                                const Scalar maximumConstraintError)
 {
+  // append values (and check dimensions)
+  inputHistory_.add(x);
+  outputHistory_.add(y);
+
+  absoluteErrorHistory_.add(Point(1, absoluteError));
+  relativeErrorHistory_.add(Point(1, relativeError));
+  residualErrorHistory_.add(Point(1, residualError));
+  constraintErrorHistory_.add(Point(1, constraintError));
+
   if (getProblem().getObjective().getOutputDimension() <= 1)
   {
+    Bool isNormal = true;
+    for (UnsignedInteger j = 0; j < x.getDimension(); ++ j)
+      if (!SpecFunc::IsNormal(x[j]))
+        isNormal = false;
+    for (UnsignedInteger j = 0; j < y.getDimension(); ++ j)
+      if (std::isnan(y[j]))
+        isNormal = false;
+
     const Bool objectiveImproved = (!getOptimalValue().getDimension())
                                    || ((getProblem().isMinimization() && y[0] < getOptimalValue()[0]) || (!getProblem().isMinimization() && y[0] > getOptimalValue()[0]));
 
     const Bool insideBounds = (!getProblem().hasBounds()) || (getProblem().hasBounds() && getProblem().getBounds().contains(x));
 
-    if ((objectiveImproved && insideBounds && (constraintError <= maximumConstraintError))
+    if ((isNormal && objectiveImproved && insideBounds && (constraintError <= maximumConstraintError))
         || getProblem().hasLevelFunction()) // consider the last value as optimal for nearest-point algos
     {
       // update values
@@ -323,15 +385,6 @@ void OptimizationResult::store(const Point & x,
       setOptimalValue(y);
     }
   }
-
-  // append values
-  absoluteErrorHistory_.store(Point(1, absoluteError));
-  relativeErrorHistory_.store(Point(1, relativeError));
-  residualErrorHistory_.store(Point(1, residualError));
-  constraintErrorHistory_.store(Point(1, constraintError));
-
-  inputHistory_.store(x);
-  outputHistory_.store(y);
 }
 
 Graph OptimizationResult::drawErrorHistory() const
@@ -386,18 +439,38 @@ Graph OptimizationResult::drawOptimalValueHistory() const
   Graph result("Optimal value history", iterationNumber_ > 0 ? "Iteration number" : "Evaluation number", "Optimal value", true, "topright", 1.0);
   result.setGrid(true);
   result.setGridColor("black");
-  Sample data(getOutputSample().getMarginal(0));
-  const UnsignedInteger size = data.getSize();
-  const Bool minimization = problem_.isMinimization();
-  for (UnsignedInteger i = 1; i < size; ++ i)
+  const Sample dataX(getInputSample());
+  Sample dataY(getOutputSample().getMarginal(0));
+  const UnsignedInteger size = dataY.getSize();
+  Scalar bestY = getProblem().isMinimization() ? SpecFunc::MaxScalar : -SpecFunc::MaxScalar;
+  UnsignedInteger firstFeasibleIndex = size;
+  const Scalar maximumConstraintError = ResourceMap::GetAsScalar("OptimizationAlgorithm-DefaultMaximumConstraintError");
+  for (UnsignedInteger i = 0; i < size; ++ i)
   {
-    const UnsignedInteger j = 0;
-    if (!((minimization && (data(i, j) < data(i - 1, j)))
-          || (!minimization && (data(i, j) > data(i - 1, j)))))
+    const Scalar y = dataY(i, 0);
+    const Point x(dataX[i]);
+    const Bool insideBounds = (!getProblem().hasBounds()) || (getProblem().hasBounds() && getProblem().getBounds().contains(x));
+    const Bool objectiveImproved = ((getProblem().isMinimization() && y < bestY) || (!getProblem().isMinimization() && y > bestY));
+    if (!std::isnan(y) && insideBounds && objectiveImproved && (constraintErrorHistory_(i, 0) < maximumConstraintError))
     {
-      data(i, j) = data(i - 1, j);
+      bestY = y;
+      // store first feasible index
+      if (firstFeasibleIndex >= size)
+        firstFeasibleIndex = i;
     }
+    else
+      dataY(i, 0) = bestY;
   }
+
+  // iteration index and optimal value
+  Sample data(size, 1);
+  for (UnsignedInteger i = 0; i < size; ++ i)
+    data(i, 0) = i;
+  data.stack(dataY);
+
+  // ignore values before first feasible point
+  data = data.split(firstFeasibleIndex);
+
   Curve optimalValueCurve(data, "optimal value");
   optimalValueCurve.setLegend("optimal value");
   result.add(optimalValueCurve);
@@ -495,5 +568,37 @@ IndicesCollection OptimizationResult::getParetoFrontsIndices() const
   return paretoFrontsIndices_;
 }
 
+/* Status message accessor */
+void OptimizationResult::setStatusMessage(const String & statusMessage)
+{
+  statusMessage_ = statusMessage;
+}
+
+String OptimizationResult::getStatusMessage() const
+{
+  return statusMessage_;
+}
+
+void OptimizationResult::setStatus(const UnsignedInteger status)
+{
+  status_ = status;
+}
+
+UnsignedInteger OptimizationResult::getStatus() const
+{
+  return status_;
+}
+
+/* Elapsed time accessor */
+void OptimizationResult::setTimeDuration(const Scalar time)
+{
+  time_ = time;
+}
+
+Scalar OptimizationResult::getTimeDuration() const
+{
+  return time_;
+}
+
 END_NAMESPACE_OPENTURNS
 
