@@ -2,7 +2,7 @@
 /**
  *  @brief ComplexMatrixImplementation implements the classical mathematicalComplexMatrixImplementation
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -906,51 +906,50 @@ Bool ComplexMatrixImplementation::isHermitian() const
 
 
 /* Check if the matrix is HPD */
-Bool ComplexMatrixImplementation::isHermitianPositiveDefinite(const Bool keepIntact)
+Bool ComplexMatrixImplementation::isHermitianPositiveDefinite() const
+{
+  ComplexMatrixImplementation A(*this);
+  return A.isHermitianPositiveDefiniteInPlace();
+}
+
+Bool ComplexMatrixImplementation::isHermitianPositiveDefiniteInPlace()
 {
   // Exception for null dimension
   if (getDimension() == 0) throw InvalidDimensionException(HERE) << "Cannot check the hermitian definite positiveness of an empty matrix";
-  int info;
-  int n(nbRows_);
-  char uplo('L');
-  int luplo(1);
-  if (keepIntact)
-  {
-    ComplexMatrixImplementation A(*this);
-    zpotrf_(&uplo, &n, &A[0], &n, &info, &luplo);
-    if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
-  }
-  else
-  {
-    zpotrf_(&uplo, &n, &(*this)[0], &n, &info, &luplo);
-    if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
-  }
-  return (info == 0) ;
+  int info = -1;
+  int n = nbRows_;
+  char uplo = 'L';
+  int luplo = 1;
+  zpotrf_(&uplo, &n, &(*this)[0], &n, &info, &luplo);
+  if (info < 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
+  return (info == 0);
 }
 
 /* Build the Cholesky factorization of the hermitian matrix */
-ComplexMatrixImplementation ComplexMatrixImplementation::computeCholesky(const Bool keepIntact)
+ComplexMatrixImplementation ComplexMatrixImplementation::computeCholesky() const
+{
+  ComplexMatrixImplementation A(*this);
+  return A.computeCholeskyInPlace();
+}
+
+ComplexMatrixImplementation ComplexMatrixImplementation::computeCholeskyInPlace()
 {
   // Exception for null dimension
   if (!(getDimension() > 0)) throw InvalidDimensionException(HERE) << "Cannot compute the Cholesky decomposition of an empty matrix";
-  int info;
-  int n(nbRows_);
-  char uplo('L');
-  int luplo(1);
+  int info = 0;
+  int n = nbRows_;
+  char uplo = 'L';
+  int luplo = 1;
 
-  ComplexMatrixImplementation Q;
-  if (keepIntact) Q = ComplexMatrixImplementation(*this);
-  ComplexMatrixImplementation & A = keepIntact ? Q : *this;
-
-  zpotrf_(&uplo, &n, &A[0], &n, &info, &luplo);
+  zpotrf_(&uplo, &n, &(*this)[0], &n, &info, &luplo);
   if (info != 0) throw InternalException(HERE) << "Lapack ZPOTRF: error code=" << info;
   for (UnsignedInteger j = 0; j < (UnsignedInteger)(n); ++j)
     for (UnsignedInteger i = 0; i < (UnsignedInteger)(j); ++i)
-      A(i, j) = 0.0;//Complex(0.0, 0.0);
+      operator()(i, j) = 0.0;//Complex(0.0, 0.0);
   // Check return code from Lapack
   if(info != 0)
     throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
-  return A;
+  return *this;
 }
 
 /* Comparison operator */
