@@ -2,7 +2,7 @@
 /**
  *  @brief Implementation for sensitivity algorithms
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,7 @@
 #include "openturns/SobolIndicesExperiment.hxx"
 #include "openturns/Normal.hxx"
 #include "openturns/KernelSmoothing.hxx"
-#include "openturns/ComposedDistribution.hxx"
+#include "openturns/JointDistribution.hxx"
 #include "openturns/Dirac.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -136,7 +136,7 @@ Point SobolIndicesAlgorithmImplementation::getFirstOrderIndices(const UnsignedIn
   }
   const UnsignedInteger outputDimension = outputDesign_.getDimension();
   if (marginalIndex >= outputDimension)
-    throw InvalidArgumentException(HERE) << "In SobolIndicesAlgorithmImplementation::getTotalOrderIndices, marginalIndex should be in [0," << outputDimension - 1;
+    throw InvalidArgumentException(HERE) << "In SobolIndicesAlgorithmImplementation::getFirstOrderIndices, marginalIndex should be in [0," << outputDimension - 1 << "]";
   // return value
   const Point firstOrderSensitivity(varianceI_[marginalIndex] / referenceVariance_[marginalIndex]);
   return firstOrderSensitivity;
@@ -193,8 +193,6 @@ void SobolIndicesAlgorithmImplementation::computeBootstrapDistribution() const
 {
   // Build interval using sample variance
   // Mean reference is the Sensitivity values
-  const Point aggregatedFirstOrder(getAggregatedFirstOrderIndices());
-  const Point aggregatedTotalOrder(getAggregatedTotalOrderIndices());
   if (bootstrapSize_ > 0)
   {
     // Temporary samples that stores the first/total indices
@@ -252,8 +250,8 @@ void SobolIndicesAlgorithmImplementation::setConfidenceInterval(const Point & va
   const UnsignedInteger inputDimension = inputDescription_.getSize();
   Point standardDeviationFO(inputDimension);
   Point standardDeviationTO(inputDimension);
-  ComposedDistribution::DistributionCollection marginalsFO(inputDimension);
-  ComposedDistribution::DistributionCollection marginalsTO(inputDimension);
+  JointDistribution::DistributionCollection marginalsFO(inputDimension);
+  JointDistribution::DistributionCollection marginalsTO(inputDimension);
   const Point aggregatedFO(getAggregatedFirstOrderIndices());
   const Point aggregatedTO(getAggregatedTotalOrderIndices());
   Bool allNormalFO = true;
@@ -282,12 +280,12 @@ void SobolIndicesAlgorithmImplementation::setConfidenceInterval(const Point & va
   if (allNormalFO)
     firstOrderIndiceDistribution_ = Normal(aggregatedFO, standardDeviationFO, CorrelationMatrix(inputDimension));
   else
-    firstOrderIndiceDistribution_ = ComposedDistribution(marginalsFO);
+    firstOrderIndiceDistribution_ = JointDistribution(marginalsFO);
 
   if (allNormalTO)
     totalOrderIndiceDistribution_ = Normal(aggregatedTO, standardDeviationTO, CorrelationMatrix(inputDimension));
   else
-    totalOrderIndiceDistribution_ = ComposedDistribution(marginalsTO);
+    totalOrderIndiceDistribution_ = JointDistribution(marginalsTO);
 }
 
 
@@ -742,7 +740,6 @@ Graph SobolIndicesAlgorithmImplementation::DrawImportanceFactors(const Point & v
   for (UnsignedInteger i = 0; i < dimension; ++i) data[i] = values[i] / l1Norm;
 
   /* build labels and colors for the pie */
-  Description palette(dimension);
   Description labels(dimension);
   Description description(names);
   // If no description has been given for the input distribution components, give standard ones
@@ -902,6 +899,7 @@ void SobolIndicesAlgorithmImplementation::save(Advocate & adv) const
   PersistentObject::save(adv);
   adv.saveAttribute( "inputDescription_", inputDescription_ );
   adv.saveAttribute( "outputDesign_", outputDesign_ );
+  adv.saveAttribute( "inputDesign_", inputDesign_ );
   adv.saveAttribute( "size_", size_ );
   adv.saveAttribute( "bootstrapSize_", bootstrapSize_ );
   adv.saveAttribute( "confidenceLevel_", confidenceLevel_ );
@@ -923,6 +921,7 @@ void SobolIndicesAlgorithmImplementation::load(Advocate & adv)
   PersistentObject::load(adv);
   adv.loadAttribute( "inputDescription_", inputDescription_ );
   adv.loadAttribute( "outputDesign_", outputDesign_ );
+  adv.loadAttribute( "inputDesign_", inputDesign_ );
   adv.loadAttribute( "size_", size_ );
   adv.loadAttribute( "bootstrapSize_", bootstrapSize_ );
   adv.loadAttribute( "confidenceLevel_", confidenceLevel_ );
