@@ -2,7 +2,7 @@
 /**
  *  @brief The Normal distribution
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -439,8 +439,12 @@ Scalar Normal::computeProbability(const Interval & interval) const
 {
   if (interval.isEmpty()) return 0.0;
   const UnsignedInteger dimension = getDimension();
-  // The generic implementation provided by the DistributionImplementation upper class is more accurate than the generic implementation provided by the ContinuousDistribution upper class for dimension = 1
-  if (dimension == 1) return DistributionImplementation::computeProbability(interval);
+  if (interval.getDimension() != dimension)
+    throw InvalidArgumentException(HERE) << "computeProbability expected an interval of dimension=" << dimension_ << ", got dimension=" << interval.getDimension();
+
+  if (dimension == 1)
+    return computeProbabilityGeneral1D(interval.getLowerBound()[0], interval.getUpperBound()[0]);
+
   // Decompose and normalize the interval
   Point lower(normalize(interval.getLowerBound()));
   Point upper(normalize(interval.getUpperBound()));
@@ -529,6 +533,8 @@ Scalar Normal::computeScalarQuantile(const Scalar prob,
                                      const Bool tail) const
 {
   if (dimension_ != 1) throw InvalidDimensionException(HERE) << "Error: the method computeScalarQuantile is only defined for 1D distributions";
+  if (!((prob >= 0.0) && (prob <= 1.0)))
+    throw InvalidArgumentException(HERE) << "computeScalarQuantile expected prob to belong to [0,1], but is " << prob;
   return mean_[0] + sigma_[0] * DistFunc::qNormal(prob, tail);
 } // computeScalarQuantile
 
@@ -749,11 +755,11 @@ Scalar Normal::computeRadialDistributionCDF(const Scalar radius,
 }
 
 /* Correlation matrix accessor */
-void Normal::setCorrelation(const CorrelationMatrix & R)
+void Normal::setR(const CorrelationMatrix & R)
 {
   // Perform checks at the upper level
   // This call set also the range
-  EllipticalDistribution::setCorrelation(R);
+  EllipticalDistribution::setR(R);
   // Then check for independence
   checkIndependentCopula();
 }
