@@ -2,7 +2,7 @@
 /**
  *  @brief The Trapezoidal distribution
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -300,6 +300,8 @@ Point Trapezoidal::computeCDFGradient(const Point & point) const
 Scalar Trapezoidal::computeScalarQuantile(const Scalar prob,
     const Bool tail) const
 {
+  if (!((prob >= 0.0) && (prob <= 1.0)))
+    throw InvalidArgumentException(HERE) << "computeScalarQuantile expected prob to belong to [0,1], but is " << prob;
   const Scalar c1 = 0.5 * (b_ - a_) * h_;
   const Scalar c2 = c1 + (c_ - b_) * h_;
   const Scalar q = tail ? 1.0 - prob : prob;
@@ -311,6 +313,13 @@ Scalar Trapezoidal::computeScalarQuantile(const Scalar prob,
   return d_ - std::sqrt(2.0 * (d_ - c_) * (1.0 - q) / h_);
 }
 
+Scalar Trapezoidal::computeProbability(const Interval & interval) const
+{
+  if (interval.getDimension() != 1)
+    throw InvalidArgumentException(HERE) << "computeProbability expected an interval of dimension=" << dimension_ << ", got dimension=" << interval.getDimension();
+  return computeProbabilityGeneral1D(interval.getLowerBound()[0], interval.getUpperBound()[0]);
+}
+
 /* Compute the entropy of the distribution */
 Scalar Trapezoidal::computeEntropy() const
 {
@@ -331,13 +340,13 @@ void Trapezoidal::computeMean() const
 }
 
 /* Get the standard deviation of the distribution */
-Point Trapezoidal::getStandardDeviation() const /*throw(NotDefinedException)*/
+Point Trapezoidal::getStandardDeviation() const
 {
   return Point(1, getSigma());
 }
 
 /* Get the skewness of the distribution */
-Point Trapezoidal::getSkewness() const /*throw(NotDefinedException)*/
+Point Trapezoidal::getSkewness() const
 {
   const Scalar a2 = a_ * a_;
   const Scalar a3 = a2 * a_;
@@ -365,7 +374,7 @@ Point Trapezoidal::getSkewness() const /*throw(NotDefinedException)*/
 }
 
 /* Get the kurtosis of the distribution */
-Point Trapezoidal::getKurtosis() const /*throw(NotDefinedException)*/
+Point Trapezoidal::getKurtosis() const
 {
   const Scalar a2 = a_ * a_;
   const Scalar a3 = a2 * a_;
