@@ -118,7 +118,7 @@ view = otv.View(graph)
 # **Stationary GEV modeling via the profile log-likelihood function**
 #
 # Now, we use the profile log-likehood function rather than log-likehood function  to estimate the parameters of the GEV.
-result_PLL = factory.buildMethodOfProfileLikelihoodMaximizationEstimator(sample)
+result_PLL = factory.buildMethodOfXiProfileLikelihoodEstimator(sample)
 
 # %%
 # The following graph allows one to get the profile log-likelihood plot.
@@ -237,10 +237,11 @@ timeStamps = data[:, 0]
 #       \xi(t) & = \beta_4
 #     \end{align*}
 constant = ot.SymbolicFunction(["t"], ["1.0"])
-basis_lin = ot.Basis([constant, ot.SymbolicFunction(["t"], ["t"])])
-basis_cst = ot.Basis([constant])
+basis = ot.Basis([constant, ot.SymbolicFunction(["t"], ["t"])])
 # basis for mu, sigma, xi
-basis_coll = [basis_lin, basis_cst, basis_cst]
+muIndices = [0, 1]  # linear
+sigmaIndices = [0]  # stationary
+xiIndices = [0]  # stationary
 
 # %%
 # We can now estimate the list of coefficients :math:`\vect{\beta} = (\beta_1, \beta_2, \beta_3, \beta_4)` using the log-likelihood of the data.
@@ -254,37 +255,50 @@ basis_coll = [basis_lin, basis_cst, basis_cst]
 #   and it differs from the result obtained with normalized data. The results are not optimal in that case
 #   since the associated log-likelihood are much smaller than those obtained with normalized data.
 #
-initiPoint_list = list()
-initiPoint_list.append("Gumbel")
-initiPoint_list.append("Static")
-normMethod_list = list()
-normMethod_list.append("MinMax")
-normMethod_list.append("CenterReduce")
-normMethod_list.append("None")
 ot.ResourceMap.SetAsUnsignedInteger(
-    "GeneralizedExtremeValueFactory-MaximumEvaluationNumber", 1000000
+    "GeneralizedExtremeValueFactory-MaximumCallsNumber", 1000000
 )
 print("Linear mu(t) model: ")
-for normMeth in normMethod_list:
-    for initPoint in initiPoint_list:
-        print("normMeth, initPoint = ", normMeth, initPoint)
+for normMeth in ["MinMax", "CenterReduce", "None"]:
+    for initPoint in ["Gumbel", "Static"]:
+        print(f"normMeth = {normMeth}, initPoint = {initPoint}")
         # The ot.Function() is the identity function.
         result = factory.buildTimeVarying(
-            sample, timeStamps, basis_coll, ot.Function(), initPoint, normMeth
+            sample,
+            timeStamps,
+            basis,
+            muIndices,
+            sigmaIndices,
+            xiIndices,
+            ot.Function(),
+            ot.Function(),
+            ot.Function(),
+            initPoint,
+            normMeth,
         )
         beta = result.getOptimalParameter()
-        print("beta1, beta2, beta3, beta4 = ", beta)
-        print("Max log-likelihood =  ", result.getLogLikelihood())
+        print(f"beta = {beta}")
+        print(f"Max log-likelihood = {result.getLogLikelihood()}")
 
 # %%
 # According to the previous results, we choose the *MinMax* normalization method and the *Gumbel* initial point.
 # This initial point is cheaper than the *Static* one as it requires no optimization computation.
 result_NonStatLL = factory.buildTimeVarying(
-    sample, timeStamps, basis_coll, ot.Function(), "Gumbel", "MinMax"
+    sample,
+    timeStamps,
+    basis,
+    muIndices,
+    sigmaIndices,
+    xiIndices,
+    ot.Function(),
+    ot.Function(),
+    ot.Function(),
+    "Gumbel",
+    "MinMax",
 )
 beta = result_NonStatLL.getOptimalParameter()
 print("Linear mu(t) model : ")
-print("beta1, beta2, beta3, beta_4 = ", beta)
+print(f"beta = {beta}")
 print(f"mu(t) = {beta[0]:.4f} + {beta[1]:.4f} * tau")
 print(f"sigma = = {beta[2]:.4f}")
 print(f"xi = = {beta[3]:.4f}")
@@ -422,12 +436,21 @@ print(f"p-value={resultLikRatioTest.getPValue():.2f}")
 #       \sigma(t) & = \beta_4 \\
 #       \xi(t) & = \beta_5
 #     \end{align*}
-basis_quad = ot.Basis(
+basis = ot.Basis(
     [constant, ot.SymbolicFunction(["t"], ["t"]), ot.SymbolicFunction(["t"], ["t^2"])]
 )
-basis_coll_2 = [basis_quad, basis_cst, basis_cst]
 result_NonStatLL_2 = factory.buildTimeVarying(
-    sample, timeStamps, basis_coll_2, ot.Function(), "Gumbel", "MinMax"
+    sample,
+    timeStamps,
+    basis,
+    [0, 1, 2],
+    [0],
+    [0],
+    ot.Function(),
+    ot.Function(),
+    ot.Function(),
+    "Gumbel",
+    "MinMax",
 )
 beta = result_NonStatLL_2.getOptimalParameter()
 print("Quadratic mu(t) model : ")
